.. toctree::
   :caption: Usage Guide
   :hidden:

   Introduction <introduction>
   Command-line interface <cli>
   introduction_to_ifermi


.. toctree::
   :caption: Information
   :hidden:

   changelog
   contributors
   contributing
   license
   IFermi on GitHub <https://github.com/fermisurfaces/IFermi>


.. toctree::
   :caption: Function Reference
   :maxdepth: -1
   :hidden:

   API reference <ifermi>
   genindex

.. include:: introduction.rst
